@@ -82,7 +82,7 @@ annotatedDataFrameFromMatrix <- function(object, byrow=FALSE, ...) {
         dimLabels <-
             if (byrow) c("featureNames", "featureColumns")
             else c("sampleNames", "sampleColumns")
-        new("AnnotatedDataFrame", data=data, dimLabels=dimLabels)
+        AnnotatedDataFrame(data=data, dimLabels=dimLabels)
     }
 }
 
@@ -94,7 +94,7 @@ annotatedDataFrameFromNull <- function(object, byrow=FALSE, ...) {
     dimLabels <-
         if (byrow) c("featureNames", "featureColumns")
         else c("sampleNames", "sampleColumns")
-    new("AnnotatedDataFrame", data=data.frame(), dimLabels=dimLabels)
+    AnnotatedDataFrame(data=data.frame(), dimLabels=dimLabels)
 }
 
 setMethod("annotatedDataFrameFrom",
@@ -115,6 +115,16 @@ setMethod("annotatedDataFrameFrom",
           signature(object="AssayData"),
           annotatedDataFrameFromAssayData)
 
+setMethod("dimnames", "AnnotatedDataFrame", function(x) {
+    dimnames(pData(x))
+})
+
+setReplaceMethod("dimnames", "AnnotatedDataFrame", function(x, value) {
+    sampleNames(x) <- value[[1]]
+    varLabels(x) <- value[[2]]
+    x
+})
+
 setMethod("dim", "AnnotatedDataFrame", function( x ) {
   d <- dim(pData(x))
   names(d) <- dimLabels(x)
@@ -141,8 +151,8 @@ setReplaceMethod("pData",
                    object="AnnotatedDataFrame",
                    value="data.frame"),
                  function(object, value) {
-                     varMetadata <-
-                         varMetadata(object)[names(value),,drop=FALSE]
+                     idx <- match(names(value), rownames(varMetadata(object)))
+                     varMetadata <- varMetadata(object)[idx,,drop=FALSE]
                      row.names(varMetadata) <- names(value)
                      initialize(object, data=value, varMetadata=varMetadata)
                  })
@@ -154,7 +164,7 @@ setReplaceMethod("sampleNames",
     signature(object="AnnotatedDataFrame", value="ANY"),
     function(object, value) 
 {
-    if (length(value) != dim(object@data)[[1]])
+    if (!is.null(value) && (length(value) != dim(object@data)[[1]]))
         stop("number of new names (", length(value), ") ",
              "should equal number of rows in AnnotatedDataFrame (",
              dim( object )[[1]], ")")
@@ -179,12 +189,15 @@ setReplaceMethod("varLabels",
     signature("AnnotatedDataFrame", "ANY"),
     function(object, value) 
 {
-    if (length(value) != dim(object@data)[[2]])
+    if (!is.null(value) && (length(value) != dim(object@data)[[2]]))
         stop("number of new varLabels (", length(value), ") ",
              "should equal number of columns in AnnotatedDataFrame (",
              dim(object)[[2]], ")")
-    colnames(object@data) <- value
-    row.names(object@varMetadata) <- value
+    if (!is.null(value)) {
+        ## silently ignore attempts to set colnames to NULL
+        colnames(object@data) <- value
+        row.names(object@varMetadata) <- value
+    }
     object
 })
 
@@ -276,14 +289,14 @@ setAs("phenoData", "AnnotatedDataFrame", function(from) {
     warning("contents of varLabels ignored\n", call.=FALSE)
   else
     varMetadata[["labelDescription"]] <- as.character(rep(NA, nrow(varLabels)))
-  new("AnnotatedDataFrame",
+  AnnotatedDataFrame(
       data=data,
       varMetadata=varMetadata,
       dimLabels=c("sampleNames", "sampleColumns"))
 })
 
 setAs("data.frame", "AnnotatedDataFrame",
-      function(from) new("AnnotatedDataFrame", data=from))
+      function(from) AnnotatedDataFrame(data=from))
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 selectSome <- function(obj, maxToShow=5) {
   len <- length(obj)
@@ -452,17 +465,17 @@ read.AnnotatedDataFrame <-
       filename, Sys.info()["nodename"], date())
     attr(vmd, "provenance") = provenance
     
-    new("AnnotatedDataFrame", data=pData, varMetadata=vmd)
+    AnnotatedDataFrame(data=pData, varMetadata=vmd)
     
 }
 
 setMethod("AnnotatedDataFrame",
           signature(data="missing", varMetadata="missing"),
 
-      function(data, varMetadata, dimLabels=c("rowNames", "columnNames"), ...)
+    function(data, varMetadata, dimLabels=c("rowNames", "columnNames"), ...)
 {
-    AnnotatedDataFrame(data=data.frame(), varMetadata=data.frame(),
-                   dimLabels=dimLabels, ...)
+    .AnnotatedDataFrame(data=data.frame(), varMetadata=data.frame(),
+                        dimLabels=dimLabels, ...)
 })
 
 setMethod("AnnotatedDataFrame",
@@ -472,8 +485,8 @@ setMethod("AnnotatedDataFrame",
 {
     varMetadata <- data.frame(labelDescription = rep(NA, ncol(data)))
     row.names(varMetadata) <- names(data)
-    AnnotatedDataFrame(data=data, varMetadata=varMetadata,
-                       dimLabels=dimLabels,...)
+    .AnnotatedDataFrame(data=data, varMetadata=varMetadata,
+                        dimLabels=dimLabels,...)
 })
 
 setMethod("AnnotatedDataFrame",
@@ -486,8 +499,8 @@ setMethod("AnnotatedDataFrame",
     row.names(varMetadata) <- names(data)
     varMetadata[["labelDescription"]] <-
         as.character(varMetadata[["labelDescription"]])
-    new("AnnotatedDataFrame", data=data, varMetadata=varMetadata,
-        dimLabels=dimLabels, ...)
+    .AnnotatedDataFrame(data=data, varMetadata=varMetadata,
+                        dimLabels=dimLabels, ...)
 })
 
 
